
# Slot: contributes to


holds between two entities where the occurrence, existence, or activity of one causes or contributes to the occurrence or generation of the other

URI: [biolink:contributes_to](https://w3id.org/biolink/vocab/contributes_to)

## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [causes](causes.md)

## Used by

 * [NamedThing](NamedThing.md)
